@@ -76,7 +76,10 @@ impl<K: Ord> SearchIndex<K> {
     /// #       search_index.insert(&index, element)
     /// #   );
     /// #
-    /// let autocomplete_options = search_index.autocomplete_global("1100 e");
+    /// let autocomplete_options = search_index.autocomplete_global(
+    ///     &5,
+    ///     "1100 e"
+    /// );
     ///
     /// assert_eq!(
     ///     autocomplete_options,
@@ -89,18 +92,35 @@ impl<K: Ord> SearchIndex<K> {
     /// ```
 
     #[tracing::instrument(level = "trace", name = "Global Autocomplete", skip(self))]
-    pub(crate) fn autocomplete_global(&self, string: &str) -> Vec<String> {
+    pub(crate) fn autocomplete_global(
+        &self,
+        maximum_autocomplete_options: &usize,
+        string: &str,
+    ) -> Vec<String> {
 
         // Split search `String` into keywords according to the `SearchIndex`
         // settings. Force "use entire string as a keyword" option off:
         let mut keywords: Vec<String> = self.string_keywords(string, false);
 
+        // For debug builds:
+        #[cfg(debug_assertions)]
+        tracing::trace!("Autocompleting: {:?}", keywords);
+
         // Pop the last keyword off the list. It's the keyword that we'll be
         // autocompleting:
         if let Some(last_keyword) = keywords.pop() {
 
             // Autocomplete the last keyword:
-            let autocompletions = self.autocomplete_keyword(&last_keyword);
+            let autocompletions: Vec<&String> = self.autocomplete_keyword(
+                maximum_autocomplete_options,
+                &last_keyword
+            ) // autocomplete_keyword
+                .iter()
+                .cloned()
+                // Only keep this autocompletion if hasn't already been used as
+                // a keyword:
+                .filter(|last_keyword| !keywords.contains(last_keyword))
+                .collect();
 
             // Push a blank placeholder onto the end of the keyword list. We
             // will be putting our autocompletions for the last keyword into
