@@ -1,5 +1,6 @@
 use crate::simple::{Indexable, SearchIndex};
 use std::cmp::Ord;
+use std::collections::HashSet;
 
 // -----------------------------------------------------------------------------
 
@@ -14,31 +15,24 @@ impl<K: Ord> SearchIndex<K> {
     pub(crate) fn indexable_keywords(
         &self,
         value: &dyn Indexable,
-    ) -> Vec<String> {
+    ) -> HashSet<String> {
 
         // The implemented trait method `strings()` will return the strings from
         // the record that are meant to be indexed:
         let strings = value.strings();
 
         // Store the individual keywords from these strings:
-        let mut keywords: Vec<String> = strings
+        strings
             // Iterate over each `String` field from the record:
             .iter()
             // Split each `String` into keywords according to the `SearchIndex`
-            // settings. `string_keywords` will allow "use entire string as a
-            // keyword" if enabled in user settings:
+            // settings. Note that `string_keywords` will allow "use entire
+            // string as a keyword" if enabled in user settings:
             .map(|string| self.string_keywords(string, true))
             // Flatten the string's keywords:
             .flatten()
             // Collect all keywords into a `Vec`:
-            .collect();
-
-        // Sort keywords & remove duplicates:
-        keywords.sort_unstable();
-        keywords.dedup();
-
-        // Return keywords to caller:
-        keywords
+            .collect()
 
     } // fn
 
